aboutsummaryrefslogtreecommitdiff
path: root/gdb/tui/tuiDisassem.c
diff options
context:
space:
mode:
authorJason Molenda <jmolenda@apple.com>2000-02-02 00:21:19 +0000
committerJason Molenda <jmolenda@apple.com>2000-02-02 00:21:19 +0000
commitd9fcf2fb1c12d48f657c974dc5b6898022bf9ccf (patch)
tree174ea6281f2933a803a1a4dc262133a462934b6d /gdb/tui/tuiDisassem.c
parentda59e08184255e09e51e54bb356e4448d33b2245 (diff)
downloadgdb-d9fcf2fb1c12d48f657c974dc5b6898022bf9ccf.zip
gdb-d9fcf2fb1c12d48f657c974dc5b6898022bf9ccf.tar.gz
gdb-d9fcf2fb1c12d48f657c974dc5b6898022bf9ccf.tar.bz2
import gdb-2000-02-01 snapshot
Diffstat (limited to 'gdb/tui/tuiDisassem.c')
-rw-r--r--gdb/tui/tuiDisassem.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gdb/tui/tuiDisassem.c b/gdb/tui/tuiDisassem.c
index a39574b..a6df694 100644
--- a/gdb/tui/tuiDisassem.c
+++ b/gdb/tui/tuiDisassem.c
@@ -43,7 +43,7 @@ tuiSetDisassemContent (s, startAddr)
#endif
{
TuiStatus ret = TUI_FAILURE;
- GDB_FILE *gdb_dis_out;
+ struct ui_file *gdb_dis_out;
if (startAddr != (Opaque) NULL)
{
@@ -65,7 +65,7 @@ tuiSetDisassemContent (s, startAddr)
lineWidth = disassemWin->generic.width - 1;
threshold = (lineWidth - 1) + offset;
/* now init the gdb_file structure */
gdb_dis_out = tui_sfileopen (threshold);
INIT_DISASSEMBLE_INFO_NO_ARCH (asmInfo, gdb_dis_out, (fprintf_ftype) fprintf_filtered);
@@ -118,7 +118,7 @@ tuiSetDisassemContent (s, startAddr)
/* reset the buffer to empty */
tui_file_get_strbuf (gdb_dis_out)[0] = '\0';
}
- gdb_file_delete (gdb_dis_out);
+ ui_file_delete (gdb_dis_out);
gdb_dis_out = NULL;
disassemWin->generic.contentSize = curLine;
ret = TUI_SUCCESS;
@@ -65,7 +65,7 @@ tuiSetDisassemContent (s, startAddr)
lineWidth = disassemWin->generic.width - 1;
threshold = (lineWidth - 1) + offset;
- /* now init the gdb_file structure */
+ /* now init the ui_file structure */
gdb_dis_out = tui_sfileopen (threshold);
INIT_DISASSEMBLE_INFO_NO_ARCH (asmInfo, gdb_dis_out, (fprintf_ftype) fprintf_filtered);